Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Telco Network Builder.

Actions, resources, and condition keys for AWS Telco Network Builder - Service Authorization Reference

# Actions, resources, and condition keys for AWS Telco Network Builder

AWS Telco Network Builder (service prefix: `tnb` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Telco Network Builder
- Resource types defined by AWS Telco Network Builder
- Condition keys for AWS Telco Network Builder

## Actions defined by AWS Telco Network Builder

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelSolNetworkOperation | Grants permission to cancel a network operation | Write | network-operation* |  |
CreateSolFunctionPackage | Grants permission to create a function package | Write | function-package* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSolNetworkInstance | Grants permission to create a network instance | Write | network-instance* |  |
network-package* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSolNetworkPackage | Grants permission to create a network package | Write | network-package* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteSolFunctionPackage | Grants permission to delete a function package | Write | function-package* |  |
DeleteSolNetworkInstance | Grants permission to delete a network instance | Write | network-instance* |  |
DeleteSolNetworkPackage | Grants permission to delete a network package | Write | network-package* |  |
GetSolFunctionInstance | Grants permission to get a function instance | Read | function-instance* |  |
| aws:ResourceTag/${TagKey} |
GetSolFunctionPackage | Grants permission to get a function package | Read | function-package* |  |
| aws:ResourceTag/${TagKey} |
GetSolFunctionPackageContent | Grants permission to get a function package contents | Read | function-package* |  |
| aws:ResourceTag/${TagKey} |
GetSolFunctionPackageDescriptor | Grants permission to get a function package descriptor | Read | function-package* |  |
| aws:ResourceTag/${TagKey} |
GetSolNetworkInstance | Grants permission to get a network instance | Read | network-instance* |  |
| aws:ResourceTag/${TagKey} |
GetSolNetworkOperation | Grants permission to get a network operation | Read | network-operation* |  |
| aws:ResourceTag/${TagKey} |
GetSolNetworkPackage | Grants permission to get a network package | Read | network-package* |  |
| aws:ResourceTag/${TagKey} |
GetSolNetworkPackageContent | Grants permission to get a network package contents | Read | network-package* |  |
| aws:ResourceTag/${TagKey} |
GetSolNetworkPackageDescriptor | Grants permission to get a network package descriptor | Read | network-package* |  |
| aws:ResourceTag/${TagKey} |
InstantiateSolNetworkInstance | Grants permission to instantiate a network instance | Write | network-instance* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
ListSolFunctionInstances | Grants permission to list function instances | List | function-instance* |  |
| aws:ResourceTag/${TagKey} |
ListSolFunctionPackages | Grants permission to list function packages | List | function-package* |  |
| aws:ResourceTag/${TagKey} |
ListSolNetworkInstances | Grants permission to list network instances | List | network-instance* |  |
| aws:ResourceTag/${TagKey} |
ListSolNetworkOperations | Grants permission to list network operations | List | network-operation* |  |
| aws:ResourceTag/${TagKey} |
ListSolNetworkPackages | Grants permission to list network packages | List | network-package* |  |
| aws:ResourceTag/${TagKey} |
ListTagsForResource | Grants permission to return a list of tags for a resource | List |  |  |
PutSolFunctionPackageContent | Grants permission to upload function package content | Write | function-package* |  |
PutSolNetworkPackageContent | Grants permission to upload network package content | Write | network-package* |  |
TagResource | Grants permission to add tags to the specified resource | Tagging | function-instance |  |
function-package |  |
network-instance |  |
network-operation |  |
network-package |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TerminateSolNetworkInstance | Grants permission to terminate a network instance | Write | network-instance* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from the specified resource | Tagging | function-instance |  |
function-package |  |
network-instance |  |
network-operation |  |
network-package |  |
| aws:TagKeys |
UpdateSolFunctionPackage | Grants permission to update a function package | Write | function-package* |  |
UpdateSolNetworkInstance | Grants permission to update a network instance | Write | function-instance* |  |
network-instance* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateSolNetworkPackage | Grants permission to update a network package | Write | network-package* |  |
ValidateSolFunctionPackageContent | Grants permission to validate function package content | Write | function-package* |  |
ValidateSolNetworkPackageContent | Grants permission to validate network package content | Write | network-package* |  |

## Resource types defined by AWS Telco Network Builder

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
function-package | `arn:$ { Partition}:tnb:$ { Region}:$ { Account}:function-package/$ { FunctionPackageId}` | aws:ResourceTag/${TagKey}
network-package | `arn:$ { Partition}:tnb:$ { Region}:$ { Account}:network-package/$ { NetworkPackageId}` | aws:ResourceTag/${TagKey}
network-instance | `arn:$ { Partition}:tnb:$ { Region}:$ { Account}:network-instance/$ { NetworkInstanceId}` | aws:ResourceTag/${TagKey}
function-instance | `arn:$ { Partition}:tnb:$ { Region}:$ { Account}:function-instance/$ { FunctionInstanceId}` | aws:ResourceTag/${TagKey}
network-operation | `arn:$ { Partition}:tnb:$ { Region}:$ { Account}:network-operation/$ { NetworkOperationId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Telco Network Builder

AWS Telco Network Builder defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by checking the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by checking tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.